@@ -19,6 +19,7 @@ Class::Accessor::Lite->mk_accessors( @$rwaccessors );
 my $DefaultMTA = Sisimai::MTA->index;
 my $DefaultMSP = Sisimai::MSP->index;
 my @HeaderList = @{ __PACKAGE__->makeheaders };
+my $ExtModules = [];
 
 sub ENDOFEMAIL { '__END_OF_EMAIL_MESSAGE__' };
 
@@ -61,6 +62,19 @@ sub makeheaders {
             push @$headerlist, $q;
         }
     }
+
+    OTHERS: for my $e ( qw|Sisimai::RFC3834| ) {
+        # Load MTA modules saved in lib/Sisimai directory
+        eval { Module::Load::load $e };
+        next if $@;
+
+        for my $v ( @{ $e->headerlist } ) {
+            # Get header name which required each MTA module
+            my $q = lc $v;
+            next if grep { $q eq $_ } @$headerlist;
+            push @$headerlist, $q;
+        }
+    }
     return $headerlist;
 }
 
@@ -77,8 +91,8 @@ sub new {
     my $messageobj = undef;
     my $parameters = undef;
 
-    for my $e ( 'mtalist', 'msplist' ) {
-        # Order of MTA, MSP
+    for my $e ( 'load', 'mtalist', 'msplist' ) {
+        # Order of MTA, MSP modules
         next unless exists $argvs->{ $e };
         next unless ref $argvs->{ $e } eq 'ARRAY';
         next unless scalar @{ $argvs->{ $e } };
@@ -110,7 +124,7 @@ sub resolve {
     my @mtamodules = ();
     my @mspmodules = ();
 
-    for my $e ( 'mtalist', 'msplist' ) {
+    for my $e ( 'load', 'mtalist', 'msplist' ) {
         # The order of MTA modules specified by user
         next unless exists $argvs->{ $e };
         next unless ref $argvs->{ $e } eq 'ARRAY';
@@ -118,11 +132,36 @@ sub resolve {
 
         push @mtamodules, @{ $argvs->{'mtalist'} } if $e eq 'mtalist';
         push @mspmodules, @{ $argvs->{'msplist'} } if $e eq 'msplist';
+
+        next unless $e eq 'load';
+
+        # Load user defined MTA module
+        for my $v ( @{ $argvs->{'load'} } ) {
+            # Load user defined MTA module
+            eval { Module::Load::load $v };
+            next if $@;
+
+            for my $w ( @{ $v->headerlist } ) {
+                # Get header name which required user defined MTA module
+                my $q = lc $w;
+                next if grep { $q eq $_ } @HeaderList;
+                unshift @HeaderList, $q;
+            }
+            push @$ExtModules, $v;
+        }
     }
 
-    # Default order of MTA modules
-    push @mtamodules, @$DefaultMTA;
-    push @mspmodules, @$DefaultMSP;
+    for my $e ( @mtamodules ) {
+        # Append the custom order of MTA modules
+        next if grep { $e eq $_ } @$DefaultMTA;
+        unshift @$DefaultMTA, $e;
+    }
+
+    for my $e ( @mspmodules ) {
+        # Append the custom order of MTA modules
+        next if grep { $e eq $_ } @$DefaultMSP;
+        unshift @$DefaultMSP, $e;
+    }
 
     EMAIL_PROCESSING: {
         my $endofheads = 0;     # Flag: The end of the email header
@@ -356,6 +395,13 @@ sub rewrite {
             last(SCANNER) if $scannedset;
         }
 
+        EXT: for my $r ( @$ExtModules ) {
+            # Call user defined MTA modules
+            $scannedset = $r->scan( $mailheader, $bodystring );
+            last(EXT) if $scannedset;
+        }
+        last(SCANNER) if $scannedset;
+
         MTA: for my $r ( @$DefaultMTA ) {
             # Pre-process email headers of a bounce message in standard format.
             # Famous MTAs, such as Sendmail, Postfix, and qmail...
@@ -376,11 +422,15 @@ sub rewrite {
 
         # When the all of Sisimai::MTA::* modules did not return bounce data,
         # call Sisimai::RFC3464;
-        #
         require Sisimai::RFC3464;
         $scannedset = Sisimai::RFC3464->scan( $mailheader, $bodystring );
         last(SCANNER) if $scannedset;
 
+        # Try to parse the message as auto reply message defined in RFC3834
+        require Sisimai::RFC3834;
+        $scannedset = Sisimai::RFC3834->scan( $mailheader, $bodystring );
+        last(SCANNER) if $scannedset;
+
         # as of now, we have no sample email for coding this block
         last;
 
@@ -429,6 +479,14 @@ C<new()> is a constructor of Sisimai::Message
     my $mailtxt = 'Entire email text';
     my $message = Sisimai::Message->new( 'data' => $mailtxt );
 
+If you have implemented a custom MTA module and use it, set the value of "load"
+in the argument of this method as an array reference like following code:
+
+    my $message = Sisimai::Message->new( 
+                        'data' => $mailtxt,
+                        'load' => [ 'Your::Custom::MTA::Module' ]
+                  );
+
 =head1 INSTANCE METHODS
 
 =head2 C<B<(from)>>
