@@ -44,7 +44,7 @@ my $RxEMS = qr{(?>                                          # Subject:
     )
 }xi;
 
-sub version     { '4.0.25' };
+sub version     { '4.0.26' };
 sub description { 'Fallback Module for MTAs' };
 sub smtpagent   { 'RFC3464' };
 
@@ -178,6 +178,11 @@ sub scan {
                 #   case characters.
                 $v->{'action'} = lc $1;
 
+                if( $v->{'action'} =~ m/\A([^ ]+)[ ]/ ) {
+                    # failed (bad destination mailbox address)
+                    $v->{'action'} = $1;
+                }
+
             } elsif( $e =~ m/\A[Ss]tatus:[ ]*(\d[.]\d+[.]\d+)/ ) {
                 # 2.3.4 Status field
                 #   The per-recipient Status field contains a transport-independent
@@ -448,6 +453,10 @@ sub scan {
             $e->{'reason'}    = $scannedset->{'reason'} || 'undefined';
             $e->{'diagnosis'} = $scannedset->{'message'} if length $scannedset->{'message'};
             $e->{'command'}   = '';
+
+        } else {
+            # Set the value of smtpagent
+            $e->{'agent'} = __PACKAGE__->smtpagent;
         }
         $e->{'status'} ||= Sisimai::RFC3463->getdsn( $e->{'diagnosis'} );
         $e->{'command'}  = $1 if $e->{'diagnosis'} =~ $RxCmd;
@@ -461,7 +470,6 @@ sub scan {
 
         $e->{'date'}  ||= $mhead->{'date'};
         $e->{'spec'}  ||= 'SMTP';
-        $e->{'agent'} ||= __PACKAGE__->smtpagent;
     }
     return { 'ds' => $dscontents, 'rfc822' => $rfc822part };
 }
