@@ -66,6 +66,15 @@ Sisimai::Reason::ExceedLimit - Bounce reason is C<exceedlimit> or not.
 Sisimai::Reason::ExceedLimit checks the bounce reason is C<exceedlimit> or not.
 This class is called only Sisimai::Reason class.
 
+This is the error that a message was rejected due to an email exceeded the 
+limit. The value of D.S.N. is 5.2.3. This reason is almost the same as 
+C<MesgTooBig>, we think.
+
+    ... while talking to mx.example.org.:
+    >>> MAIL From:<kijitora@example.co.jp> SIZE=16600348
+    <<< 552 5.2.3 Message size exceeds fixed maximum message size (10485760)
+    554 5.0.0 Service unavailable
+
 =head1 CLASS METHODS
 
 =head2 C<B<text()>>
@@ -85,6 +94,14 @@ C<match()> returns 1 if the argument matched with patterns defined in this class
 C<true()> returns 1 if the bounce reason is C<exceedlimit>. The argument must be
 Sisimai::Data object and this method is called only from Sisimai::Reason class.
 
+=head1 SEE ALSO
+
+=over
+
+=item L<Sisimai::Reason::MesgTooBig> - Sisimai::Reason::MesgTooBig
+
+=back
+
 =head1 AUTHOR
 
 azumakuniyuki
