@@ -70,6 +70,14 @@ Sisimai::Reason::NoRelaying - Bounce reason is C<norelaying> or not.
 Sisimai::Reason::NoRelaying checks the bounce reason is C<norelaying> or not.
 This class is called only Sisimai::Reason class.
 
+This is the error that SMTP connection rejected with error message 
+C<Relaying Denied>. This reason does not exist in any version of bounceHammer.
+
+    ... while talking to mailin-01.mx.example.com.:
+    >>> RCPT To:<kijitora@example.org>
+    <<< 554 5.7.1 <kijitora@example.org>: Relay access denied
+    554 5.0.0 Service unavailable
+
 =head1 CLASS METHODS
 
 =head2 C<B<text()>>
