@@ -59,8 +59,18 @@ Sisimai::Reason::SecurityError - Bounce reason is C<securityerror> or not.
 
 =head1 DESCRIPTION
 
-Sisimai::Reason::SecurityError checks the bounce reason is C<securityerror> or not.
-This class is called only Sisimai::Reason class.
+Sisimai::Reason::SecurityError checks the bounce reason is C<securityerror> or 
+not. This class is called only Sisimai::Reason class.
+
+This is the error that a security violation was detected on a destination mail 
+server. Depends on the security policy on the server, there is any virus in the
+email, a sender's email address is camouflaged address. Sisimai will set
+C<securityerror> to the reason of email bounce if the value of Status: field in
+a bounce email is C<5.7.*>.
+
+    Status: 5.7.0
+    Remote-MTA: DNS; gmail-smtp-in.l.google.com
+    Diagnostic-Code: SMTP; 552-5.7.0 Our system detected an illegal attachment on your message. Please
 
 =head1 CLASS METHODS
 
