@@ -59,6 +59,13 @@ Sisimai::Reason::SystemError - Bounce reason is C<systemerror> or not.
 Sisimai::Reason::SystemError checks the bounce reason is C<systemerror> or not.
 This class is called only Sisimai::Reason class.
 
+This is the error that an email has bounced due to system error on the remote
+host such as LDAP connection failure or other internal system error.
+
+    <kijitora@example.net>: 
+    Unable to contact LDAP server. (#4.4.3)I'm not going to try again; this
+    message has been in the queue too long.
+
 =head1 CLASS METHODS
 
 =head2 C<B<text()>>
